/*
 * Copyright (C)2005-2019 Haxe Foundation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package php;

/**
	This type can be used in places where externs use associative arrays as a list of configuration options.
	This type is a special case for Haxe->Php generator: object declaration is generated as php array declaration whenever
	that object declaration is passed directly to a variable or a function argument of this type.
**/
@:forward
abstract NativeStructArray<T:{}>(NativeArray) to NativeArray {
	@:from @:pure(false)
	static function __fromObject<T:{}>(obj:T):NativeStructArray<T> {
		return cast Syntax.array(obj);
	}

	@:to
	inline function __toObject():T {
		return Boot.createAnon(this);
	}

	@:arrayAccess
	inline function get<V>(key:String):V
		return this[key];

	@:arrayAccess
	inline function set<V>(key:String, val:V):V
		return this[key] = val;
}
